import json
from django.core.serializers.json import DjangoJSONEncoder
from django.views.generic.base import TemplateView


class GraphQLPlaygroundView(TemplateView):
    template_name = "playground/playground.html"

    endpoint = None
    subscription_endpoint=None
    workspace_name=None
    config=None
    settings=None

    def __init__(self,
                 endpoint=None,
                 subscription_endpoint=None,
                 workspace_name=None,
                 config=None,
                 settings=None,
                 **kwargs):
        super(GraphQLPlaygroundView, self).__init__(**kwargs)
        self.options = {
            'endpoint': endpoint,
            'subscriptionEndpoint': subscription_endpoint,
            'workspaceName': workspace_name,
            'config': config,
            'settings': settings,
        }

    def get_context_data(self, *args, **kwargs):
        context = super(GraphQLPlaygroundView, self).get_context_data(*args, **kwargs)
        context['options'] = json.dumps(self.options, cls=DjangoJSONEncoder)
        return context



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-graphql-playground',
    version='1.0',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',  # example license
    description='Apollo GraphQL Playground as a Django view',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://jaydenwindle.com/',
    author='Jayden Windle',
    author_email='jaydenwindle@gmail.com',
)